from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from moderator.constants import DEFAULT_CONFIG
from secretballot.models import Vote
from moderator.models import ClassifiedComment
from celery.task import task


@task(ignore_result=True)
def flag_reported_comments_task(comment):
    classified_comment, created = ClassifiedComment.objects.get_or_create(
        comment=comment
    )
    comment_content_type = ContentType.objects.get_for_model(comment)
    moderator_settings = getattr(settings, 'MODERATOR', DEFAULT_CONFIG)
    if Vote.objects.filter(
        content_type=comment_content_type,
        object_id=comment.id,
        vote=-1
    ).count() >= moderator_settings['ABUSE_CUTOFF']:
        comment.is_removed = True
        comment.save()
        classified_comment.cls = 'reported'
        classified_comment.save()



from django import template

register = template.Library()


@register.inclusion_tag('moderator/inclusion_tags/report_comment_abuse.html',
                        takes_context=True)
def report_comment_abuse(context, obj):
    """
    Checks whether a user can report abuse (has not liked comment previously)
    or has reported abuse previously and renders appropriate response.

    If requesting user is part of the 'Moderators' group a vote equal to
    ABUSE_CUTOFF setting will be made, thereby immediately marking the comment
    as abusive.
    """
    context.update({
        'content_obj': obj,
        'vote': -1,
        'content_type': "-".join((obj._meta.app_label, obj._meta.module_name)),
    })
    return context
